@@ -27,7 +27,7 @@ from pathlib import Path
 
 from pyfakefs import fake_filesystem_unittest
 from pyfakefs.helpers import get_uid, set_uid, is_root, IS_PYPY
-from pyfakefs.tests.test_utils import RealFsTestMixin
+from pyfakefs.tests.test_utils import RealFsTestMixin, skip_if_symlink_not_supported
 
 is_windows = sys.platform == "win32"
 
@@ -212,6 +212,26 @@ class FakeShutilModuleTest(RealFsTestCase):
         self.assertTrue(os.path.exists(dst_file))
         self.assertEqual(os.stat(src_file).st_mode, os.stat(dst_file).st_mode)
 
+    def test_permission_error_message(self):
+        self.check_posix_only()
+        dst_dir = Path(self.make_path("home1"))
+        src_dir2 = os.path.join(dst_dir, "dir1")
+        os.makedirs(src_dir2)
+        dst_dir.chmod(0o555)
+        src_dir = Path(self.make_path("drive1"))
+        os.makedirs(src_dir)
+        src_file = src_dir / "new.txt"
+        src_file.touch()
+
+        msg = f"[Errno 13] Permission denied: '{dst_dir}'"
+        with self.assertRaises(PermissionError, msg=msg):
+            shutil.copy2(src_file, dst_dir)
+
+        dst_dir2 = dst_dir / "dir2"
+        msg = f"[Errno 13] Permission denied: '{dst_dir2}'"
+        with self.assertRaises(PermissionError, msg=msg):
+            shutil.move(src_dir2, dst_dir2)
+
     def test_copy_directory(self):
         src_file = self.make_path("xyzzy")
         parent_directory = self.make_path("parent")
@@ -244,7 +264,7 @@ class FakeShutilModuleTest(RealFsTestCase):
     @unittest.skipIf(IS_PYPY, "Functionality not supported in PyPy")
     def test_copystat_symlinks(self):
         """Regression test for #799"""
-        self.skip_if_symlink_not_supported()
+        skip_if_symlink_not_supported()
         f = self.make_path("xyzzy")
         self.create_file(f)
         sym1 = self.make_path("sym1")
@@ -434,7 +454,7 @@ class FakeCopyFileTest(RealFsTestCase):
             shutil.copyfile(src_file, dst_file)
 
     def test_raises_if_dest_is_a_symlink_to_src(self):
-        self.skip_if_symlink_not_supported()
+        skip_if_symlink_not_supported()
         src_file = self.make_path("foo")
         dst_file = self.make_path("bar")
         contents = "contents of file"
